@@ -1,10 +1,10 @@
 /**
  * @file   latexmk.c
- * @brief  
+ * @brief
  *
- * Copyright (C) 2010-2011 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009 Gummi Developers
  * All Rights reserved.
- * 
+ *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
  * files (the "Software"), to deal in the Software without
@@ -37,17 +37,17 @@
 gboolean lmk_detected = FALSE;
 
 void latexmk_init (void) {
-    
+
     if (external_exists (C_LATEXMK)) {
         // TODO: check if supported version
-        slog (L_INFO, "Typesetter detected: Latexmk %s\n", 
+        slog (L_INFO, "Typesetter detected: Latexmk %s\n",
                        external_version (C_LATEXMK));
         lmk_detected = TRUE;
     }
 }
 
 gboolean latexmk_active (void) {
-    if (STR_EQU (config_get_value("typesetter"), C_LATEXMK)) {
+    if (config_value_as_str_equals ("Compile", "typesetter", C_LATEXMK)) {
         return TRUE;
     }
     return FALSE;
@@ -59,17 +59,17 @@ gboolean latexmk_detected (void) {
 
 gchar* latexmk_get_command (const gchar* method, gchar* workfile, gchar* basename) {
     gchar* outdir = g_strdup("");
-    gchar* base;
 
-    /* reroute output files to our temp directory */
+    // reroute output files to our temp directory
     if (!STR_EQU (C_TMPDIR, g_path_get_dirname (workfile))) {
+        gchar* base;
         base = g_path_get_basename (basename);
         outdir = g_strdup_printf ("-jobname=\"%s/%s\"", C_TMPDIR, base);
     }
-    
+
     const gchar* flags = latexmk_get_flags (method);
     gchar* lmkcmd;
-    
+
     lmkcmd = g_strdup_printf("latexmk %s %s \"%s\"", flags, outdir, workfile);
     return lmkcmd;
 }
@@ -79,7 +79,7 @@ gchar* latexmk_get_flags (const gchar *method) {
     gchar* lmkwithoutput;
     gchar* lmkflags;
 
-    if (config_get_value("synctex")) {
+    if (config_get_boolean ("Compile", "synctex")) {
         if (STR_EQU (method, "texpdf")) {
             lmkflags = g_strdup_printf("-e \"\\$pdflatex = 'pdflatex -synctex=1'\" -silent");
         }
@@ -95,7 +95,7 @@ gchar* latexmk_get_flags (const gchar *method) {
             lmkflags = g_strdup_printf("-e \"\\$latex = 'latex -synctex=0'\" -silent");
         }
     }
-    
+
     if (STR_EQU (method, "texpdf")) {
         lmkwithoutput = g_strconcat (lmkflags, " -pdf", NULL);
     }
@@ -105,7 +105,7 @@ gchar* latexmk_get_flags (const gchar *method) {
     else {
         lmkwithoutput = g_strconcat (lmkflags, " -pdfps", NULL);
     }
-    
+
     g_free (lmkflags);
     return lmkwithoutput;
 }
