@@ -30,6 +30,7 @@
 #include "configfile.h"
 
 #include <glib.h>
+#include <string.h>
 #include <sys/stat.h>
 
 #include "constants.h"
@@ -48,7 +49,6 @@ const gchar default_config[] =
 "mainwindow_max = false\n"
 "toolbar = true\n"
 "statusbar = true\n"
-"rightpane = true\n"
 "snippets = true\n"
 "[Editor]\n"
 "font = Monospace 14\n"
@@ -78,7 +78,7 @@ const gchar default_config[] =
 "[Compile]\n"
 "typesetter = pdflatex\n"
 "steps = texpdf\n"
-"status = true\n"
+"pause = false\n"
 "scheme = on_idle\n"
 "timer = 1\n"
 "shellescape = true\n"
@@ -96,17 +96,13 @@ gchar *conf_filepath = 0;
 
 
 void config_init () {
-    gchar* template_path;
-
     conf_filepath = g_build_filename (C_GUMMI_CONFDIR, "gummi.ini", NULL);
-    template_path = g_build_path (G_DIR_SEPARATOR_S, C_GUMMI_CONFDIR, "templates", NULL);
 
     // create config & template dirs if not exists:
-    if (!g_file_test (template_path, G_FILE_TEST_IS_DIR)) {
+    if (!g_file_test (C_GUMMI_TEMPLATEDIR, G_FILE_TEST_IS_DIR)) {
         slog (L_WARNING, "Template directory does not exist, creating..\n");
-        g_mkdir_with_parents (template_path, DIR_PERMS);
+        g_mkdir_with_parents (C_GUMMI_TEMPLATEDIR, DIR_PERMS);
     }
-    g_free (template_path);
 
     // load config file:
     g_autoptr(GError) error = NULL;
@@ -126,8 +122,9 @@ void config_init () {
     gchar* text;
     if (g_file_get_contents (C_WELCOMETEXT, &text, NULL, NULL)) {
         guint hash = g_str_hash (text); // thank you mr daniel bernstein
-
-        if (hash == -676241409) { // 0.6.6 default text - or unhappy collision
+        if (hash == -676241409 || // 0.6.6
+            hash == 1654921927 || // 0.7.999
+            hash == 66148856) {   // 0.8.0 dev
             slog (L_WARNING, "Replacing unchanged welcome text with new default\n");
             utils_copy_file (C_DEFAULTTEXT, C_WELCOMETEXT, NULL);
         }
