@@ -35,7 +35,7 @@
 // Gummi defs:
 #define C_PACKAGE "gummi"
 #define C_PACKAGE_NAME "Gummi"
-#define C_PACKAGE_VERSION "git"
+#define C_PACKAGE_VERSION "0.8.1"
 #define C_PACKAGE_COMMENTS "Simple LaTeX Editor for GTK+"
 #define C_PACKAGE_COPYRIGHT "Copyright \xc2\xa9 2009\n\n"\
                             "Alexander van der Meij\n"\
@@ -113,6 +113,7 @@
 
 // Default paths:
 #define C_GUMMI_CONFDIR g_build_path (G_DIR_SEPARATOR_S, g_get_user_config_dir(), "gummi", NULL)
+#define C_GUMMI_TEMPLATEDIR g_build_path (G_DIR_SEPARATOR_S, C_GUMMI_CONFDIR, "templates", NULL)
 
 // Default documents:
 #define C_WELCOMETEXT g_build_filename (C_GUMMI_CONFDIR, "welcome.tex", NULL)
@@ -122,6 +123,7 @@
 #define C_LATEX "latex"
 #define C_PDFLATEX "pdflatex"
 #define C_XELATEX "xelatex"
+#define C_LUALATEX "lualatex"
 #define C_RUBBER "rubber"
 #define C_LATEXMK "latexmk"
 
@@ -129,7 +131,7 @@
 #define C_CD_TMPDIR g_strdup_printf ("cd \"%s\"%s%s",C_TMPDIR,C_CMDSEP,C_TEXSEC)
 #define C_DIRSEP G_DIR_SEPARATOR_S
 
-// Platform dependant path definitions:
+// Platform dependent path definitions:
 #ifdef WIN32
     #define C_TMPDIR utils_get_tmp_tmp_dir()
     #define C_CMDSEP "&&"
