@@ -96,8 +96,6 @@ GummiGui* gui_init (GtkBuilder* builder) {
         GTK_STATUSBAR (gtk_builder_get_object (builder, "statusbar"));
     g->rightpane =
         GTK_BOX (gtk_builder_get_object (builder, "box_rightpane"));
-    g->previewoff = GTK_TOGGLE_TOOL_BUTTON (
-            gtk_builder_get_object (builder, "tool_previewoff"));
     g->errorview =
         GTK_TEXT_VIEW (gtk_builder_get_object (builder, "errorview"));
     g->errorbuff =
@@ -110,8 +108,6 @@ GummiGui* gui_init (GtkBuilder* builder) {
         GTK_CHECK_MENU_ITEM (gtk_builder_get_object (builder, "menu_toolbar"));
     g->menu_statusbar =
         GTK_CHECK_MENU_ITEM(gtk_builder_get_object (builder, "menu_statusbar"));
-    g->menu_rightpane =
-        GTK_CHECK_MENU_ITEM(gtk_builder_get_object (builder, "menu_rightpane"));
     g->statusid =
         gtk_statusbar_get_context_id (GTK_STATUSBAR (g->statusbar), "Gummi");
     g->recent[0] =
@@ -205,12 +201,9 @@ GummiGui* gui_init (GtkBuilder* builder) {
     hpaned= GTK_WIDGET (gtk_builder_get_object (builder, "hpaned"));
     gtk_paned_set_position (GTK_PANED (hpaned), (width/2));
 
-#ifndef USE_GTKSPELL
-    gtk_widget_set_sensitive (GTK_WIDGET (g->menu_spelling), FALSE);
-#else
     if (config_get_boolean ("Editor", "spelling"))
         gtk_check_menu_item_set_active (g->menu_spelling, TRUE);
-#endif
+
     if (config_get_boolean ("Interface", "snippets")) {
         gtk_check_menu_item_set_active (g->menu_snippets, TRUE);
         gtk_widget_show (GTK_WIDGET (g->menu_snippets));
@@ -233,15 +226,6 @@ GummiGui* gui_init (GtkBuilder* builder) {
         gtk_widget_hide (GTK_WIDGET (g->statusbar));
     }
 
-    if (config_get_boolean ("Interface", "rightpane")) {
-        gtk_check_menu_item_set_active (g->menu_rightpane, TRUE);
-        gtk_widget_show (GTK_WIDGET (g->rightpane));
-    } else {
-        config_set_boolean ("Compile", "status", FALSE);
-        gtk_toggle_tool_button_set_active (g->previewoff, FALSE);
-        gtk_widget_hide (GTK_WIDGET (g->rightpane));
-    }
-
     g->menu_autosync =
         GTK_CHECK_MENU_ITEM (gtk_builder_get_object (builder, "menu_autosync"));
 
@@ -251,9 +235,6 @@ GummiGui* gui_init (GtkBuilder* builder) {
         gtk_check_menu_item_set_active (g->menu_autosync, (async? TRUE: FALSE));
     }
 
-    if (!config_get_boolean ("Compile", "status"))
-        gtk_toggle_tool_button_set_active (g->previewoff, TRUE);
-
     g->recent_list[0] = g_strdup (config_get_string ("Misc", "recent1"));
     g->recent_list[1] = g_strdup (config_get_string ("Misc", "recent2"));
     g->recent_list[2] = g_strdup (config_get_string ("Misc", "recent3"));
@@ -265,49 +246,10 @@ GummiGui* gui_init (GtkBuilder* builder) {
     return g;
 }
 
-
-G_MODULE_EXPORT
-gboolean on_w32button_clicked (GtkWidget* widget, void* user) {
-	#ifdef WIN32
-		gtk_widget_hide (gui->w32window);
-	#endif
-	return TRUE;
-}
-
-#ifdef WIN32
-gboolean w32popup_wait_event (void *builder) {
-
-	const gchar* count = gtk_label_get_text (GTK_LABEL (gui->w32label));
-	gint number = atoi (count) - 1;
-
-	if (number == 0) {
-
-		gtk_label_set_text (GTK_LABEL (gui->w32label), "");
-		gtk_widget_set_sensitive (gui->w32button, TRUE);
-		return FALSE;
-	}
-	gtk_label_set_text (GTK_LABEL (gui->w32label),
-						g_strdup_printf("%d", number));
-	return TRUE;
-}
-#endif
-
 void gui_main (GtkBuilder* builder) {
     gtk_builder_connect_signals (builder, NULL);
     gtk_widget_show_all (GTK_WIDGET (gui->mainwindow));
 
-	#ifdef WIN32
-    gui->w32window =
-			GTK_WIDGET (gtk_builder_get_object (builder, "w32popup"));
-	gui->w32button =
-			GTK_WIDGET (gtk_builder_get_object (builder, "w32button"));
-	gui->w32label =
-			GTK_WIDGET (gtk_builder_get_object (builder, "w32label"));
-    gtk_widget_show (gui->w32window);
-
-    g_timeout_add_seconds (1, w32popup_wait_event, NULL);
-    #endif
-
     gtk_main ();
 }
 
@@ -509,7 +451,7 @@ void gui_set_hastabs_sensitive (gboolean enable) {
 
 G_MODULE_EXPORT
 void on_menu_bibupdate_activate (GtkWidget *widget, void * user) {
-    biblio_compile_bibliography (gummi->biblio, g_active_editor, gummi->latex);
+    biblio_compile_bibliography (gummi->biblio, g_active_editor);
 }
 
 G_MODULE_EXPORT
@@ -518,19 +460,6 @@ gboolean on_docstats_close_clicked (GtkWidget* widget, void* user) {
     return TRUE;
 }
 
-G_MODULE_EXPORT
-void on_tool_previewoff_toggled (GtkWidget *widget, void * user) {
-    gboolean value =
-        gtk_toggle_tool_button_get_active (GTK_TOGGLE_TOOL_BUTTON (widget));
-
-    config_set_boolean ("Compile", "status", value);
-
-    if (value)
-        previewgui_stop_preview (gui->previewgui);
-    else
-        previewgui_start_preview (gui->previewgui);
-}
-
 G_MODULE_EXPORT
 void on_tool_textstyle_bold_activate (GtkWidget* widget, void* user) {
     editor_set_selection_textstyle (g_active_editor, "tool_bold");
@@ -606,8 +535,8 @@ void on_template_rowitem_edited (GtkWidget* widget, gchar *path, gchar* filenm,
     GtkTreeModel* model = NULL;
     GtkTreeSelection* selection = NULL;
     gchar* text = NULL;
-    gchar* filepath = g_build_filename (g_get_user_config_dir (),
-            "gummi", "templates", filenm, NULL);
+
+    gchar* filepath = g_build_filename (C_GUMMI_TEMPLATEDIR, filenm, NULL);
 
     model = gtk_tree_view_get_model (gummi->templ->templateview);
     selection = gtk_tree_view_get_selection (gummi->templ->templateview);
@@ -645,17 +574,16 @@ void on_button_biblio_compile_clicked (GtkWidget* widget, void* user) {
     gtk_widget_set_sensitive (widget, FALSE);
     g_timeout_add (10, on_bibprogressbar_update, widget);
 
-    if (biblio_compile_bibliography (gummi->biblio, g_active_editor,
-                gummi->latex)) {
+    if (biblio_compile_bibliography (gummi->biblio, g_active_editor)) {
         statusbar_set_message (_("Compiling bibliography file.."));
-        // NOTE gtk3s bar doesnt place text inside the widget anymore :/
+        // NOTE gtk3s bar doesn't place text inside the widget anymore :/
         //gtk_progress_bar_set_text (gummi->biblio->progressbar,
         //        _("Bibliography compiled without errors"));
         motion_force_compile (gummi->motion);
     } else {
         statusbar_set_message
         (_("Error compiling bibliography file or none detected.."));
-        // NOTE gtk3s bar doesnt place text inside the widget anymore :/
+        // NOTE gtk3s bar doesn't place text inside the widget anymore :/
         //gtk_progress_bar_set_text (gummi->biblio->progressbar,
         //        _("Error compiling bibliography file"));
     }
@@ -673,7 +601,7 @@ void on_button_biblio_detect_clicked (GtkWidget* widget, void* user) {
     g_timeout_add (2, on_bibprogressbar_update, widget);
     gtk_list_store_clear (gummi->biblio->list_biblios);
 
-    if (biblio_detect_bibliography (gummi->biblio, g_active_editor)) {
+    if (biblio_detect_bibliography (g_active_editor)) {
         editor_insert_bib (g_active_editor, g_active_editor->bibfile);
         if (!g_file_get_contents(g_active_editor->bibfile, &text, NULL, &err)) {
             slog (L_G_ERROR, "g_file_get_contents (): %s\n", err->message);
@@ -690,7 +618,7 @@ void on_button_biblio_detect_clicked (GtkWidget* widget, void* user) {
         str = g_strdup_printf ("%d", number);
         gtk_label_set_text (gummi->biblio->refnr_label, str);
         g_free (str);
-        // NOTE gtk3s bar doesnt place text inside the widget anymore :/
+        // NOTE gtk3s bar doesn't place text inside the widget anymore :/
         //gtk_progress_bar_set_text (gummi->biblio->progressbar, str);
         g_free (basename);
     }
@@ -699,7 +627,7 @@ void on_button_biblio_detect_clicked (GtkWidget* widget, void* user) {
                     (GTK_WIDGET(gummi->biblio->list_filter), FALSE);
         statusbar_set_message
         (_("No bibliography file detected in document.."));
-        // NOTE gtk3s bar doesnt place text inside the widget anymore :/
+        // NOTE gtk3s bar doesn't place text inside the widget anymore :/
         //gtk_progress_bar_set_text (gummi->biblio->progressbar,
         //        _("no bibliography file detected"));
         gtk_label_set_text (gummi->biblio->filenm_label, _("none"));
@@ -766,15 +694,13 @@ void typesetter_setup (void) {
     gtk_widget_set_sensitive (GTK_WIDGET (gui->prefsgui->opt_shellescape),
                               status);
 
-    gboolean texormk = (texlive_active() || latexmk_active());
-
-    if (config_get_boolean ("Compile", "synctex") && texormk) {
+    if (config_get_boolean ("Compile", "synctex")) {
         gtk_toggle_button_set_active (gui->prefsgui->opt_synctex, TRUE);
     }
     else {
         gtk_toggle_button_set_active (gui->prefsgui->opt_synctex, FALSE);
     }
-    gtk_widget_set_sensitive (GTK_WIDGET (gui->prefsgui->opt_synctex), texormk);
+    gtk_widget_set_sensitive (GTK_WIDGET (gui->prefsgui->opt_synctex), TRUE);
 
     slog (L_INFO, "Typesetter %s configured\n",
                    config_get_string ("Compile", "typesetter"));
@@ -910,6 +836,14 @@ gchar* get_save_filename (GuFilterType type) {
         g_free (dirname);
         g_free (basename);
     }
+    else {
+        gchar *unsaved = g_strdup_printf (_("Unsaved Document"));
+        if (type == TYPE_PDF)
+            unsaved = g_strconcat (unsaved, ".pdf", NULL);
+        if (type == TYPE_LATEX)
+            unsaved = g_strconcat (unsaved, ".tex", NULL);
+        gtk_file_chooser_set_current_name (chooser, unsaved);
+    }
 
     if (gtk_dialog_run (GTK_DIALOG (chooser)) == GTK_RESPONSE_OK)
         filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
