@@ -117,6 +117,8 @@ GuPrefsGui* prefsgui_init (GtkWindow* mainwindow) {
         GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "typ_pdflatex"));
     p->typ_xelatex =
         GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "typ_xelatex"));
+    p->typ_lualatex =
+        GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "typ_lualatex"));
     p->typ_rubber =
         GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "typ_rubber"));
     p->typ_latexmk =
@@ -145,10 +147,7 @@ GuPrefsGui* prefsgui_init (GtkWindow* mainwindow) {
 
     gtk_window_set_transient_for (GTK_WINDOW (p->prefwindow), mainwindow);
 
-#ifdef USE_GTKSPELL
-    /* list available languages */
-
-
+    // list available languages
     if (g_file_test (
         g_find_program_in_path("enchant-lsmod"), G_FILE_TEST_EXISTS)) {
 
@@ -170,12 +169,7 @@ GuPrefsGui* prefsgui_init (GtkWindow* mainwindow) {
         gtk_combo_box_set_active (GTK_COMBO_BOX(p->combo_languages), 0);
         g_free ((gchar*)pret.second);
     }
-#else
-    /* desensitise gtkspell related GUI elements if not used */
-    GtkWidget* box = GTK_WIDGET (
-		gtk_builder_get_object (builder, "box_spellcheck"));
-    gtk_widget_set_sensitive (box, FALSE);
-#endif
+
     GList* schemes = editor_list_style_scheme_sorted ();
     GList* schemes_iter = schemes;
     gchar* desc = NULL;
@@ -290,6 +284,13 @@ static void set_tab_compilation_settings (GuPrefsGui* prefs) {
         gtk_widget_set_tooltip_text (GTK_WIDGET(prefs->typ_xelatex), "");
     }
 
+    if (lualatex_detected()) {
+        if (lualatex_active())
+            gtk_toggle_button_set_active (prefs->typ_lualatex, TRUE);
+        gtk_widget_set_sensitive (GTK_WIDGET(prefs->typ_lualatex), TRUE);
+        gtk_widget_set_tooltip_text (GTK_WIDGET(prefs->typ_lualatex), "");
+    }
+
     if (rubber_detected()) {
         if (rubber_active())
             gtk_toggle_button_set_active (prefs->typ_rubber, TRUE);
@@ -331,12 +332,14 @@ static void set_tab_compilation_settings (GuPrefsGui* prefs) {
 }
 
 static void set_tab_preview_settings (GuPrefsGui* prefs) {
+    gboolean pause_status = config_get_boolean ("Compile", "pause");
 
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->compile_status),
-                                  config_get_boolean ("Compile", "status"));
+                                  !pause_status);
 
-    if (!config_get_boolean ("Compile", "status"))
+    if (pause_status) {
         gtk_widget_set_sensitive (GTK_WIDGET (prefs->compile_timer), FALSE);
+    }
 
     gtk_spin_button_set_value (prefs->compile_timer,
                                config_get_integer ("Compile", "timer"));
@@ -523,11 +526,12 @@ void toggle_wordwrapping (GtkWidget* widget, void* user) {
 
 G_MODULE_EXPORT
 void toggle_compilestatus (GtkWidget* widget, void* user) {
-    gboolean newval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-    config_set_boolean ("Compile", "status", newval);
+    gboolean val = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 
-    gtk_widget_set_sensitive (GTK_WIDGET(gui->prefsgui->compile_timer), newval);
-    gtk_toggle_tool_button_set_active (gui->previewoff, !newval);
+    config_set_boolean ("Compile", "pause", !val);
+
+    gtk_widget_set_sensitive (GTK_WIDGET(gui->prefsgui->compile_timer), val);
+    gtk_toggle_tool_button_set_active (gui->previewgui->preview_pause, !val);
 }
 
 G_MODULE_EXPORT
@@ -596,6 +600,7 @@ void on_prefs_close_clicked (GtkWidget* widget, void* user) {
     g_free (text);
 
     gtk_widget_hide (GTK_WIDGET (gui->prefsgui->prefwindow));
+    config_save ();
 }
 
 G_MODULE_EXPORT
@@ -679,6 +684,14 @@ void on_typ_xelatex_toggled (GtkToggleButton* widget, void* user) {
     }
 }
 
+G_MODULE_EXPORT
+void on_typ_lualatex_toggled (GtkToggleButton* widget, void* user) {
+    if (gtk_toggle_button_get_active (widget)) {
+        config_set_string ("Compile", "typesetter", "lualatex");
+        typesetter_setup ();
+    }
+}
+
 G_MODULE_EXPORT
 void on_typ_rubber_toggled (GtkToggleButton* widget, void* user) {
     if (gtk_toggle_button_get_active (widget)) {
@@ -735,7 +748,7 @@ void on_synctex_toggled (GtkToggleButton* widget, void* user) {
 
 G_MODULE_EXPORT
 void on_combo_language_changed (GtkComboBoxText* widget, void* user) {
-#ifdef USE_GTKSPELL
+
     gchar* selected = gtk_combo_box_text_get_active_text (widget);
     GList* tab = gummi->tabmanager->tabs;
     config_set_string ("Editor", "spelling_lang", selected);
@@ -750,7 +763,6 @@ void on_combo_language_changed (GtkComboBoxText* widget, void* user) {
         }
     }
     g_free(selected);
-#endif
 }
 
 G_MODULE_EXPORT
