@@ -51,9 +51,9 @@ struct _GuLatex {
 
 GuLatex* latex_init (void);
 gboolean latex_precompile_check (gchar* editortext);
-gchar* latex_update_workfile (GuLatex*  lc, GuEditor* ec);
+gchar* latex_update_workfile (GuEditor* ec);
 gboolean latex_update_pdffile (GuLatex* lc, GuEditor* ec);
-void latex_update_auxfile (GuLatex* lc, GuEditor* ec);
+void latex_update_auxfile (GuEditor* ec);
 void latex_export_pdffile (GuLatex* lc, GuEditor* ec, const gchar* path,
         gboolean prompt_overrite);
 
