@@ -2,9 +2,9 @@
  * @file    snippets.c
  * @brief   handle snppets
  *
- * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009 Gummi Developers
  * All Rights reserved.
- * 
+ *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
  * files (the "Software"), to deal in the Software without
@@ -37,18 +37,21 @@
 
 #include <glib.h>
 
+#include "constants.h"
 #include "editor.h"
 #include "environment.h"
-#include "porting.h"
 #include "utils.h"
 
-GuSnippets* snippets_init (const gchar* filename) {
+GuSnippets* snippets_init () {
     GuSnippets* s = g_new0 (GuSnippets, 1);
+
+    gchar* filename = g_build_filename (C_GUMMI_CONFDIR, "snippets.cfg", NULL);
     gchar* dirname = g_path_get_dirname (filename);
+
     g_mkdir_with_parents (dirname, DIR_PERMS);
     g_free (dirname);
 
-    slog (L_INFO, "snippets : %s\n", filename);
+    slog (L_INFO, "Snippets : %s\n", filename);
 
     s->filename = g_strdup (filename);
     s->accel_group = gtk_accel_group_new ();
@@ -291,7 +294,7 @@ gboolean snippets_key_press_cb (GuSnippets* sc, GuEditor* ec, GdkEventKey* ev) {
             g_free (key);
         }
     }
-    
+
     if (sc->info) {
         if (ev->keyval == GDK_KEY_Tab) {
             if (!snippet_info_goto_next_placeholder (sc->info, ec))
@@ -320,8 +323,9 @@ gboolean snippets_key_press_cb (GuSnippets* sc, GuEditor* ec, GdkEventKey* ev) {
     return FALSE;
 }
 
-gboolean snippets_key_release_cb (GuSnippets* sc, GuEditor* ec, GdkEventKey* e) {
-    if (e->keyval != GDK_KEY_Tab && !sc->info)
+gboolean snippets_key_release_cb (GuSnippets* sc, GuEditor* ec, GdkEventKey* ev) {
+
+    if (ev->keyval != GDK_KEY_Tab && !sc->info)
         return FALSE;
 
     if (sc->info)
